@@ -5,6 +5,8 @@ if [[ -z "$1" ]]; then
     exit 1
 fi
 
+set -euo pipefail
+
 VERSION=$1
 SCRIPT_DIR=$(dirname "$0")
 RELEASE_DATE=$(date +"%B %-d, %Y")
@@ -27,7 +29,7 @@ check_git() {
 
 update_version() {
     echo -n "Updating mwparserfromhell.__version__..."
-    sed -e 's/__version__ = .*/__version__ = "'$VERSION'"/' -i "" mwparserfromhell/__init__.py
+    sed -e 's/__version__ = .*/__version__ = "'$VERSION'"/' -i "" src/mwparserfromhell/__init__.py
     echo " done."
 }
 
@@ -101,7 +103,8 @@ test_release() {
     source bin/activate
     echo " done."
     echo -n "Installing mwparserfromhell with pip..."
-    pip -q install mwparserfromhell
+    pip -q install --upgrade pip
+    pip -q install mwparserfromhell pytest
     echo " done."
     echo -n "Checking version..."
     reported_version=$(python -c 'print(__import__("mwparserfromhell").__version__)')
@@ -134,7 +137,7 @@ test_release() {
     cd mwparserfromhell-$VERSION
     echo "Running unit tests..."
     python setup.py -q install
-    python -m unittest discover
+    python -m pytest
     if [[ "$?" != "0" ]]; then
         echo "*** ERROR: Unit tests failed!"
         deactivate
